@@ -6,13 +6,12 @@ class SDK:
     def __init__(self, merchant: dict, processor: str = None, merchant_cadena: dict = None):
         # Si se le indica el procesador
         self.processor = processor
-        if processor == 'mercadopago' and merchant['credentials']['mercadopago']['active']:
+        self._sdk = None
+        if processor == 'mercadopago':
             self._sdk = MercadoPagoSDK(merchant)
-            return
-        elif processor == 'mp_marketplace' and merchant['credentials']['mp_marketplace']['active']:
+        elif processor == 'mp_marketplace':
             self._sdk = MercadoPagoSDK(merchant, marketplace=True)
-            return
-        elif processor == 'decidir' and merchant['credentials']['decidir']['active']:
+        elif processor == 'decidir':
             self._sdk = DecidirSDK(merchant, merchant_cadena)
 
     def customer(self):
@@ -33,3 +32,5 @@ class SDK:
     def which(self):
         return self.processor
 
+    def ok(self):
+        return self._sdk.ok()
