@@ -5,6 +5,7 @@ import string
 from iso8601 import parse_date
 from ..response import ok, error
 
+
 def _format_card(response):
     if 'card' in response:
         return {
@@ -41,6 +42,7 @@ def _format_card(response):
         'expiration_year': '',
     }
 
+
 def _format(response):
     if response['status'] == 'accredited':
         response['status'] = 'approved'
@@ -60,13 +62,16 @@ def _format(response):
     }
     return result
 
+
 class Payment:
-    def __init__(self, url, private_key: str, public_key: str, payment_type: str, site_id: str):
+    def __init__(self, url, private_key: str, public_key: str, merchant_name: str, site_ids: dict,
+                 site_ids_cadena: dict = None):
         self.url = url
         self.private_key = private_key
         self.public_key = public_key
-        self.payment_type = payment_type
-        self.site_id = site_id
+        self.merchant_name = merchant_name
+        self.site_ids = site_ids
+        self.site_ids_cadena = site_ids_cadena
         self.headers = {
             'apikey': self.private_key,
             'Content-Type': 'application/json',
@@ -88,38 +93,19 @@ class Payment:
             'currency': 'ARS',
             'installments': 1,
             'payment_type': 'single',
-            'establishment_name': '-',  # opcional
+            'establishment_name': self.merchant_name,  # opcional
             'sub_payments': []
         }
-        # if self.payment_type == 'distributed':
-        #     application_fee = round(payment_data['application_fee'], 2) * 100
-        #     body['sub_payments'] = [
-        #         {
-        #             'site_id': payment_data['seller_site_id'],
-        #             'installments': 1,
-        #             'amount': total_amount - application_fee
-        #         }, {
-        #             'site_id': self.site_id,    # Cadena
-        #             'installments': 1,
-        #             'amount': application_fee
-        #         }
-        #     ]
-        # else:
-        #     body['amount'] = total_amount
-        #     body['site_id'] = self.site_id
-        if payment_data['payment_type'] == 'cobro_por_uso':
-            body['payment_type'] = 'single'
-            body['site_id'] = self.site_ids['cobro_por_uso']
+        if 'application_fee' not in payment_data:
+            body['amount'] = total_amount
+            if payment_data['payment_type'] == 'cobro_por_uso':
+                body['site_id'] = self.site_ids['cobro_por_uso']
+            elif payment_data['payment_type'] == 'checkout':
+                body['site_id'] = self.site_ids['checkout']
+            elif payment_data['payment_type'] == 'cobros_recurrentes':
+                body['site_id'] = self.site_ids['cobros_recurrentes']
 
-        elif payment_data['payment_type'] == 'checkout':
-            body['payment_type'] = 'single'
-            body['site_id'] = self.site_ids['checkout']
-
-        elif payment_data['payment_type'] == 'cobros_recurrentes':
-            body['payment_type'] = 'single'
-            body['site_id'] = self.site_ids['cobros_recurrentes']
-
-        elif payment_data['payment_type'] == 'distributed':
+        else:
             body['payment_type'] = 'distributed'
             application_fee = round(payment_data['application_fee'], 2) * 100
             body['sub_payments'] = [
@@ -131,7 +117,8 @@ class Payment:
                     'site_id': self.site_ids['distributed'],
                     'installments': 1,
                     'amount': application_fee
-                }]
+                }
+            ]
 
         # Si viene informacion adicional
         additional_information = [
@@ -154,8 +141,10 @@ class Payment:
     def get(self, payment_id: str):
         # r = requests.get(self.url + '/payments/{}'.format(payment_id), headers=self.headers)
         # return ok(_format(r.json()))
-        filters = {'siteOperationId': payment_id,
-                   'expand':'card_data'}
+        filters = {
+            'siteOperationId': payment_id,
+            'expand': 'card_data'
+        }
         r = requests.get(self.url + '/payments', params=filters, headers=self.headers)
         list_results = r.json()['results']
         if len(list_results) == 1:
