@@ -8,17 +8,20 @@ from .Refund import Refund
 
 class MercadoPagoSDK:
     def __init__(self, merchant, marketplace=False):
+        active = True
         if 'credentials' in merchant:
             if not marketplace:
                 access_token = merchant['credentials']['mercadopago']['access_token']
+                active = merchant['credentials']['mercadopago']['active']
             else:
                 access_token = merchant['credentials']['mp_marketplace']['access_token']
+                active = merchant['credentials']['mp_marketplace']['active']
         else:
             if not marketplace:
                 access_token = merchant['keys']['access_token']
             else:
                 access_token = merchant['keys_marketplace']['access_token']
-        self.sdk = mercadopago.SDK(access_token)
+        self.sdk = mercadopago.SDK(access_token) if active else None
         self.merchant_id = merchant['_id']
         self.merchant_name = merchant['name']
 
@@ -36,3 +39,6 @@ class MercadoPagoSDK:
 
     def refund(self):
         return Refund(self.sdk)
+
+    def ok(self):
+        return self.sdk is not None
